@@ -26,13 +26,16 @@ from wxbanker.bankobjects.recurringtransaction import RecurringTransaction
 from wxbanker import currencies, bankexceptions, debug
 from wxbanker.mint.api import Mint
 
+from wxbanker.currencies import CurrencyList
+from wxbanker.currconvert import CurrencyConverter
+
 import datetime
 
 class Account(ORMObject):
     ORM_TABLE = "accounts"
     ORM_ATTRIBUTES = ["Name", "Balance", "MintId"]
     
-    def __init__(self, store, aID, name, currency=0, balance=0.0, mintId=None):
+    def __init__(self, store, aID, name, currency=0, balance=0.0, mintId=None, currNick=False):
         ORMObject.__init__(self)
         self.IsFrozen = True
         self.Store = store
@@ -41,9 +44,11 @@ class Account(ORMObject):
         self._Transactions = None
         self._RecurringTransactions = []
         self._preTransactions = []
-        self.Currency = currency
-        self.Balance = balance
+        # Make sure that Currency and Balance are not None (bug #653716)
+        self.Currency = currency or 0
+        self.Balance = balance or 0.0
         self.MintId = mintId
+        self.ShowCurrencyNick = currNick or False
         self.IsFrozen = False
 
         Publisher.subscribe(self.onTransactionAmountChanged, "ormobject.updated.Transaction.Amount")
@@ -84,8 +89,19 @@ class Account(ORMObject):
 
     def GetCurrency(self):
         return self._Currency
-    
-    def GetCurrentBalance(self):
+
+    def balanceAtCurrency(self, balance, currency):
+        if currency:
+            conv = CurrencyConverter()
+            destCurrency = CurrencyList[currency]().GetCurrencyNick()
+            srcCurrency = self.GetCurrency().GetCurrencyNick()
+            return conv.Convert(balance, srcCurrency, destCurrency)
+        return balance
+
+    def GetBalance(self, currency=None):
+        return self.balanceAtCurrency(self.Balance, currency)
+
+    def GetCurrentBalance(self, currency=None):
         """Returns the balance up to and including today, but not transactions in the future."""
         currentBalance = self.Balance
         today = datetime.date.today()
@@ -95,7 +111,8 @@ class Account(ORMObject):
         while index >= 0 and transactions[index].Date > today:
             currentBalance -= transactions[index].Amount
             index -= 1
-        return currentBalance
+
+        return self.balanceAtCurrency(currentBalance, currency)
         
     def GetRecurringTransactions(self):
         return self._RecurringTransactions
@@ -328,7 +345,7 @@ class Account(ORMObject):
             debug.debug("Ignoring transaction because I am %s: %s" % (self.Name, transaction))
 
     def float2str(self, *args, **kwargs):
-        return self.Currency.float2str(*args, **kwargs)
+        return self.Currency.float2str(withNick=self.ShowCurrencyNick, *args, **kwargs)
 
     def __cmp__(self, other):
         return cmp(self.Name, other.Name)
@@ -350,4 +367,4 @@ class Account(ORMObject):
     RecurringTransactions = property(GetRecurringTransactions)
     Currency = property(GetCurrency, SetCurrency)
     MintId = property(GetMintId, SetMintId)
-    CurrentBalance = property(GetCurrentBalance)
\ No newline at end of file
+    CurrentBalance = property(GetCurrentBalance)
