@@ -17,10 +17,10 @@ class CsvExporter:
         # Iterate through transaction list, write rows.
         for account in model.Accounts:
             for transaction in account.Transactions:
-                row = [account.Name, transaction.GetDescription(), transaction.GetAmount(), transaction.GetDate()]
+                row = [account.Name.encode("utf8"), transaction.GetDescription().encode("utf8"), transaction.GetAmount(), transaction.GetDate()]
                 writer.writerow(row)
                 
-        return result.getvalue()
+        return result.getvalue().decode("utf8")
     
     @staticmethod
     def Export(model, exportPath):
@@ -28,4 +28,4 @@ class CsvExporter:
         result = CsvExporter.Generate(model)
         # Write it.
         exportFile = open(exportPath, 'w')
-        exportFile.write(result)
\ No newline at end of file
+        exportFile.write(result.encode("utf8"))
