@@ -17,15 +17,17 @@
 #    along with wxBanker.  If not, see <http://www.gnu.org/licenses/>.
 
 import wx
+from wx.lib.pubsub import Publisher
 from wxbanker.csvimporter import CsvImporter, CsvImporterProfileManager, json
 from wxbanker.transactionolv import TransactionOLV
+from wxbanker.brandedframe import BrandedFrame
 
-class CsvImportFrame(wx.Frame):
+class CsvImportFrame(BrandedFrame):
     """
     Window for importing data from a CSV file
     """
     def __init__(self):
-        wx.Frame.__init__(self, None, title=_("CSV import"))
+        BrandedFrame.__init__(self, None, title=_("CSV import"))
         # Necessary to be able to preview imports since OLV looks for this attribute on its GrandParent.
         self.searchActive = False
 
@@ -37,6 +39,7 @@ class CsvImportFrame(wx.Frame):
         topPanel = wx.Panel(self)
         topHorizontalSizer = wx.BoxSizer(wx.VERTICAL)
         topSizer = wx.BoxSizer(wx.VERTICAL)
+        topSizer.AddSpacer(6)
 
         horizontalSizer = wx.BoxSizer(wx.HORIZONTAL)
         topSizer.Add(horizontalSizer, flag=wx.EXPAND)
@@ -59,26 +62,38 @@ class CsvImportFrame(wx.Frame):
         self.Show(True)
 
     def initTargetAccountControl(self, topPanel, topSizer):
-        staticBox = wx.StaticBox(topPanel, label=_("Target account"))
-        staticBoxSizer = wx.StaticBoxSizer(staticBox, wx.HORIZONTAL)
-        topSizer.Add(staticBoxSizer, flag=wx.ALL|wx.EXPAND, border=1)
+        targetText = wx.StaticText(topPanel, label=_("Target account"))
+        targetSizer = wx.BoxSizer()
 
         try:
             bankModel = wx.GetApp().Controller.Model
             self.accountsDict = dict([(acc.GetName(), acc) for acc in bankModel.Accounts])
-            accounts = self.accountsDict.keys()
+            accounts = sorted(self.accountsDict.keys())
         except:
             accounts = []
 
-        self.targetAccountCtrl = wx.ComboBox(topPanel, style=wx.CB_READONLY, choices=accounts)
-        self.targetAccountCtrl.Bind(wx.EVT_COMBOBOX, self.onTargetAccountChange)
-        staticBoxSizer.Add(self.targetAccountCtrl)
+        self.targetAccountCtrl = wx.Choice(topPanel, choices=accounts)
 
+        self.cancelButton = wx.Button(topPanel, label=_("Cancel"))
+        self.cancelButton.SetToolTipString(_("Cancel"))
+        self.cancelButton.Bind(wx.EVT_BUTTON, lambda e: self.Destroy())
+        
         self.importButton = wx.Button(topPanel, label=_("Import"))
-        self.importButton.Disable()
         self.importButton.SetToolTipString(_("Import"))
         self.importButton.Bind(wx.EVT_BUTTON, self.onClickImportButton)
-        staticBoxSizer.Add(self.importButton, flag=wx.LEFT, border=5)
+        
+        targetSizer.AddSpacer(6)
+        targetSizer.Add(targetText, flag=wx.ALIGN_CENTER_VERTICAL)
+        targetSizer.AddSpacer(6)
+        targetSizer.Add(self.targetAccountCtrl)
+        targetSizer.AddStretchSpacer(1)
+        targetSizer.Add(self.cancelButton)
+        targetSizer.AddSpacer(6)
+        targetSizer.Add(self.importButton)
+        targetSizer.AddSpacer(6)
+        
+        topSizer.AddSpacer(6)
+        topSizer.Add(targetSizer, flag=wx.ALL|wx.EXPAND)
 
     def initSettingsControls(self, topPanel, parentSizer):
         # csv columns to wxBanker data mapping
@@ -118,6 +133,7 @@ class CsvImportFrame(wx.Frame):
 
         staticBox = wx.StaticBox(topPanel, label=_("CSV file settings"))
         staticBoxSizer = wx.StaticBoxSizer(staticBox, wx.VERTICAL)
+        topSizer.AddSpacer(6)
         topSizer.Add(staticBoxSizer, flag=wx.ALL|wx.EXPAND, border=1)
 
         sizer = wx.FlexGridSizer(rows=3, cols=2, hgap=15, vgap=0)
@@ -139,8 +155,8 @@ class CsvImportFrame(wx.Frame):
 
     def initFileAndActionControls(self, topPanel, topSizer):
         # file picker control and import button
-
         sizer = wx.BoxSizer(wx.HORIZONTAL)
+        topSizer.AddSpacer(6)
         topSizer.Add(sizer, flag=wx.EXPAND|wx.ALL, border=5)
 
         sizer.Add(wx.StaticText(topPanel, label=_('File to import')), flag=wx.ALIGN_CENTER_VERTICAL)
@@ -148,12 +164,6 @@ class CsvImportFrame(wx.Frame):
         self.filePickerCtrl.Bind(wx.EVT_FILEPICKER_CHANGED, self.onFileChange)
         sizer.Add(self.filePickerCtrl, flag=wx.EXPAND|wx.LEFT|wx.RIGHT, proportion=2, border=10)
 
-        self.previewButton = wx.Button(topPanel, label=_("Preview"))
-        self.previewButton.Disable()
-        self.previewButton.SetToolTipString(_("Preview"))
-        self.previewButton.Bind(wx.EVT_BUTTON, self.onClickPreviewButton)
-        sizer.Add(self.previewButton)
-
     def initTransactionCtrl(self, topPanel, topSizer):
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         topSizer.Add(sizer, flag=wx.EXPAND|wx.ALL, proportion=1, border=5)
@@ -175,20 +185,17 @@ class CsvImportFrame(wx.Frame):
             return
 
         self.profileCtrl = wx.ComboBox(topPanel, choices=self.profileManager.profiles.keys(), size=(110,-1))
-        self.profileCtrl.Bind(wx.EVT_TEXT, self.onProfileCtrlChange)
+        self.profileCtrl.Bind(wx.EVT_COMBOBOX, self.onProfileCtrlChange)
         sizer.Add(self.profileCtrl, flag=wx.ALIGN_CENTER)
 
-        self.loadProfileButton = wx.Button(topPanel, label=_("Load"))
-        self.loadProfileButton.Bind(wx.EVT_BUTTON, self.onClickLoadProfileButton)
-        self.loadProfileButton.Disable()
-        sizer.Add(self.loadProfileButton, flag=wx.ALIGN_CENTER)
-
+        sizer.AddSpacer(6)
         self.saveProfileButton = wx.Button(topPanel, label=_("Save"))
         self.saveProfileButton.Bind(wx.EVT_BUTTON, self.onClickSaveProfileButton)
         self.saveProfileButton.Disable()
         sizer.Add(self.saveProfileButton, flag=wx.ALIGN_CENTER)
 
-        self.deleteProfileButton = wx.Button(topPanel, label=_("Delete"))
+        sizer.AddSpacer(6)
+        self.deleteProfileButton = wx.Button(topPanel, label=_("Remove"))
         self.deleteProfileButton.Bind(wx.EVT_BUTTON, self.onClickDeleteProfileButton)
         self.deleteProfileButton.Disable()
         sizer.Add(self.deleteProfileButton, flag=wx.ALIGN_CENTER)
@@ -245,8 +252,6 @@ class CsvImportFrame(wx.Frame):
             self.showErrorDialog(_("The file encoding does not seem to be '%s'.") % settings['encoding'], e)
         except Exception, e:
             self.showErrorDialog(exc=e)
-        finally:
-            self.toggleImportButton()
 
     def showErrorDialog(self, errDetail = '', exc = None):
         errString = _('An error ocurred during the csv file import.')
@@ -257,45 +262,37 @@ class CsvImportFrame(wx.Frame):
         dlg.Destroy()
 
     def importTransactions(self):
-        account = self.accountsDict[self.targetAccountCtrl.Value]
+        account = self.accountsDict[self.targetAccountCtrl.StringSelection]
         account.AddTransactions(self.transactionContainer.Transactions)
-
-    def toggleImportButton(self):
-        self.importButton.Enable(self.targetAccountCtrl.Value != '' and self.transactionContainer is not None)
+        # Trigger an account change so the user is now looking at the imported transactions.
+        Publisher.sendMessage("user.account changed", account)
 
     def onFileChange(self, event):
         if self.filePickerCtrl.Path != '':
-            self.previewButton.Enable()
-
-    def onTargetAccountChange(self, event):
-        self.toggleImportButton()
+            self.runPreview()
 
     def onProfileCtrlChange(self, event):
         if self.profileCtrl.Value != '':
             self.saveProfileButton.Enable()
             enabled = self.profileManager.getProfile(self.profileCtrl.Value) != None
-            self.loadProfileButton.Enable(enabled)
             self.deleteProfileButton.Enable(enabled)
+            # Load it.
+            key = self.profileCtrl.Value
+            self.initCtrlValuesFromSettings(self.profileManager.getProfile(key))
         else :
-            self.loadProfileButton.Disable()
             self.saveProfileButton.Disable()
             self.deleteProfileButton.Disable()
 
-    def onClickPreviewButton(self, event):
-        self.runPreview()
-
     def onClickImportButton(self, event):
         self.importTransactions()
+        self.Destroy()
 
-    def initProfileCtrl(self):
+    def initProfileCtrl(self, value=None):
         self.profileCtrl.Items = self.profileManager.profiles.keys()
+        if self.profileCtrl.Items:
+            self.profileCtrl.Value = value or self.profileCtrl.Items[0]
         self.onProfileCtrlChange(None)
 
-    def onClickLoadProfileButton(self, event):
-        key = self.profileCtrl.Value
-        self.initCtrlValuesFromSettings(self.profileManager.getProfile(key))
-        self.initProfileCtrl()
-
     def onClickSaveProfileButton(self, event):
         key = self.profileCtrl.Value
         if self.profileManager.profiles.has_key(key):
@@ -305,7 +302,7 @@ class CsvImportFrame(wx.Frame):
             if d.ShowModal() != wx.ID_YES:
                 return
         self.profileManager.saveProfile(key, self.getSettingsFromControls())
-        self.initProfileCtrl()
+        self.initProfileCtrl(value=key)
 
     def onClickDeleteProfileButton(self, event):
         key = self.profileCtrl.Value
@@ -318,7 +315,7 @@ class DetachedTransactionOLV(TransactionOLV):
         self.SetEmptyListMsg(_('Select file and click "Preview"'))
 
     def renderFloat(self, floatVal):
-        return floatVal
+        return str(floatVal)
 
     def showContextMenu(self, transactions, col):
         TransactionOLV.showContextMenu(self, transactions, col, removeOnly=True)
