@@ -28,11 +28,13 @@ TODO (for feature parity):
 - handle batch events at UI level
 """
 
+import threading
 import wx, datetime
 from wx.lib.pubsub import Publisher
 from wxbanker.ObjectListView import GroupListView, ColumnDefn, CellEditorRegistry
 from wxbanker import bankcontrols, tagtransactiondialog
 
+from wxbanker.currencies import GetCurrencyInt
 
 class TransactionOLV(GroupListView):
     EMPTY_MSG_NORMAL = _("No transactions entered.")
@@ -45,8 +47,10 @@ class TransactionOLV(GroupListView):
         self.BankController = bankController
 
         self.showGroups = False
-        self.evenRowsBackColor = wx.Color(224,238,238)
+        #WXTODO: figure out these (and the text color, or is that already?) from theme (LP: ???)
+        self.evenRowsBackColor = wx.Colour(224,238,238)
         self.oddRowsBackColor = wx.WHITE
+
         self.cellEditMode = GroupListView.CELLEDIT_DOUBLECLICK
         self.SetEmptyListMsg(self.EMPTY_MSG_NORMAL)
 
@@ -56,14 +60,16 @@ class TransactionOLV(GroupListView):
 
         # Define some constants to use throughout.
         self.COL_DATE = 0
+        self.COL_DESCRIPTION = 1
         self.COL_AMOUNT = 2
         self.COL_TOTAL = 3
 
+        # If you change these column names, update sizeAmounts()!
         self.SetColumns([
-            ColumnDefn(_("Date"), valueGetter=self.getDateOf, valueSetter=self.setDateOf, width=dateWidth),
+            ColumnDefn(_("Date"), valueGetter=self.getDateAndIDOf, valueSetter=self.setDateOf, stringConverter=self.renderDateIDTuple, editFormatter=self.renderEditDate, width=dateWidth),
             ColumnDefn(_("Description"), valueGetter="Description", isSpaceFilling=True, editFormatter=self.renderEditDescription),
-            ColumnDefn(_("Amount"), "right", valueGetter="Amount", stringConverter=self.renderFloat, editFormatter=self.renderEditFloat),
-            ColumnDefn(_("Total"), "right", valueGetter=self.getTotal, stringConverter=self.renderFloat, isEditable=False),
+            ColumnDefn(_("Amount"), "right", valueGetter=self.getAmount, valueSetter=self.setAmount, stringConverter=self.renderFloat, editFormatter=self.renderEditFloat),
+            ColumnDefn(_("Balance"), "right", valueGetter=self.getTotal, stringConverter=self.renderFloat, isEditable=False),
         ])
         # Our custom hack in OLV.py:2017 will render amount floats appropriately as %.2f when editing.
 
@@ -80,13 +86,14 @@ class TransactionOLV(GroupListView):
             (self.onTransactionAdded, "transaction.created"),
             (self.onTransactionsRemoved, "transactions.removed"),
             (self.onCurrencyChanged, "currency_changed"),
+            (self.onShowCurrencyNickToggled, "controller.show_currency_nick_toggled"),
             (self.updateTotals, "ormobject.updated.Transaction.Amount"),
             (self.onTransactionDateUpdated, "ormobject.updated.Transaction.Date"),
         )
 
         for callback, topic in self.Subscriptions:
             Publisher.subscribe(callback, topic)
-
+        
     def SetObjects(self, objs, *args, **kwargs):
         """
         Override the default SetObjects to properly refresh the auto-size,
@@ -113,14 +120,22 @@ class TransactionOLV(GroupListView):
         self.SortBy(self.SORT_COL)
         self.updateTotals()
 
-    def getDateOf(self, transaction):
-        return str(transaction.Date)
+    def getDateAndIDOf(self, transaction):
+        # A date and ID two-tuple is used to allow for correct sorting
+        # by date (bug #653697)
+        return (transaction.Date, transaction.ID)
 
     def setDateOf(self, transaction, date):
         transaction.Date = date
         self.Freeze()
         self.SortBy(self.SORT_COL)
         self.Thaw()
+        
+    def setAmount(self, transaction, amount):
+        transaction.Amount = amount
+        self.Freeze()
+        self.SortBy(self.SORT_COL)
+        self.Thaw()
 
     def getTotal(self, transObj):
         if not hasattr(transObj, "_Total"):
@@ -133,20 +148,45 @@ class TransactionOLV(GroupListView):
         if first is None:
             return
         
-        first._Total = first.Amount
+        if not self.CurrentAccount:
+            #This means we are in 'All accounts' so we need to convert each total
+            # to the global currency
+            balance_currency = self.BankController.Model.GlobalCurrency
+        else:
+            #we are just viewing a single account
+            # balance currency = accounts currency
+            balance_currency = GetCurrencyInt(self.CurrentAccount.GetCurrency())
+        
+        first._Total = first.GetAmount(balance_currency)
         
         b = first
         for i in range(1, len(self.GetObjects())):
             a, b = b, self.GetObjectAt(i)
-            b._Total = a._Total + b.Amount
-
-    def renderFloat(self, floatVal):
-        if self.CurrentAccount:
-            return self.CurrentAccount.float2str(floatVal)
+            b._Total = a._Total + b.GetAmount(balance_currency)
+    
+    def renderDateIDTuple(self, pair):
+        return str(pair[0])
+  
+    def getAmount(self, obj):
+        #Return the whole transaction/float since we need to use its
+        #renderAmount method to support multiple currencies.
+        return obj  
+        
+    def renderFloat(self, value):
+        if isinstance(value, float):
+            #this is a 'balance' column, its ok to use the bank model's float2str
+            # as long as we'r not in an account.
+            if self.CurrentAccount:
+                return self.CurrentAccount.float2str(value)
+            else:
+                return self.BankController.Model.float2str(value)
         else:
-            #WXTODO: fix me, this function should be given the object which should have a float2str method
-            # so that for multiple currencies they can be displayed differently when viewing all.
-            return self.BankController.Model.float2str(floatVal)
+            #this is a trnasaction, so it belogns to the 'Amount' column, render
+            # it with its appropieate currency
+            return value.RenderAmount()
+    
+    def renderEditDate(self, transaction):
+        return str(transaction.Date)
     
     def renderEditFloat(self, modelObj):
         return "%.2f" % modelObj.Amount
@@ -154,7 +194,7 @@ class TransactionOLV(GroupListView):
     def renderEditDescription(self, modelObj):
         return modelObj._Description
 
-    def sizeAmounts(self):
+    def _sizeAmounts(self):
         """Set the width of the Amount and Total columns based on the approximated widest value."""
         transactions = self.GetObjects()
         # If there aren't any transactions, there's nothing to do.
@@ -165,9 +205,14 @@ class TransactionOLV(GroupListView):
             # Sort by amount, then compare the highest and lowest, to take into account a negative sign.
             sortedtrans = list(sorted(transactions, cmp=lambda a,b: cmp(getattr(a, attr), getattr(b, attr))))
             high, low = sortedtrans[0], sortedtrans[-1]
+            # Get the (translated) displayed column name to calculate width.
+            header = _({"_Total": "Balance"}.get(attr, attr))
             # Take the max of the two as well as the column header width, as we need to at least display that.
-            widestWidth = max([self.GetTextExtent(_(attr.strip("_")))[0]] + [self.GetTextExtent(self.renderFloat(getattr(t, attr)))[0] for t in (high, low)])
-            self.SetColumnFixedWidth(self.COL_AMOUNT+i, widestWidth + 10)
+            widestWidth = max([self.GetTextExtent(header)[0]] + [self.GetTextExtent(self.renderFloat(getattr(t, attr)))[0] for t in (high, low)])
+            wx.CallAfter(self.SetColumnFixedWidth, *(self.COL_AMOUNT+i, widestWidth + 10))
+
+    def sizeAmounts(self):
+        threading.Thread(target=self._sizeAmounts).start()
 
     def setAccount(self, account, scrollToBottom=True):
         self.CurrentAccount = account
@@ -351,14 +396,15 @@ class TransactionOLV(GroupListView):
             # Remove the item from the list.
             self.RemoveObjects(transactions)
             self.updateTotals()
+            self.sizeAmounts()
             
     def onTransactionAdded(self, message):
         account, transaction = message.data
         if account is self.CurrentAccount:
             self.AddObject(transaction)
             self.updateTotals()
-            #WXTODO: Perhaps get the actual position and scroll to that, it may not be last.
-            self.ensureVisible(-1)
+            self.Reveal(transaction)
+            self.sizeAmounts()
 
     def onTagSearch(self, tag):
         Publisher.sendMessage("SEARCH.EXTERNAL", str(tag))
@@ -405,7 +451,15 @@ class TransactionOLV(GroupListView):
         self.sizeAmounts()
         # Now we need to adjust the description width so we don't have a horizontal scrollbar.
         self.AutoSizeColumns()
-
+        
+    def onShowCurrencyNickToggled(self, message):
+        # Refresh all the transaction objects, re-rendering the amounts.
+        self.RefreshObjects()
+        # The current likely changed the widths of the amount/total column.
+        self.sizeAmounts()
+        # Now we need to adjust the description width so we don't have a horizontal scrollbar.
+        self.AutoSizeColumns()
+        
     def __del__(self):
         for callback, topic in self.Subscriptions:
             Publisher.unsubscribe(callback)
